import { _ as _async_to_generator } from "@swc/helpers/_/_async_to_generator";
import { _ as _object_spread } from "@swc/helpers/_/_object_spread";
import { _ as _object_spread_props } from "@swc/helpers/_/_object_spread_props";
import { _ as _ts_generator } from "@swc/helpers/_/_ts_generator";
import { execa } from "@modern-js/utils";
import { canUseNpm, canUsePnpm, canUseYarn } from "./env";
function execaWithStreamLog(command, args, options) {
  var promise = execa(command, args, _object_spread_props(_object_spread({}, options), {
    stdin: "inherit",
    stdout: "inherit",
    stderr: "inherit"
  }));
  return promise;
}
function runInstallWithNvm(command, options) {
  return _runInstallWithNvm.apply(this, arguments);
}
function _runInstallWithNvm() {
  _runInstallWithNvm = _async_to_generator(function(command, options) {
    return _ts_generator(this, function(_state) {
      switch (_state.label) {
        case 0:
          return [
            4,
            execa("~/.nvm/nvm-exec ".concat(command), _object_spread_props(_object_spread({}, options), {
              shell: true,
              stdin: "inherit",
              stdout: "inherit",
              stderr: "inherit"
            }))
          ];
        case 1:
          _state.sent();
          return [
            2
          ];
      }
    });
  });
  return _runInstallWithNvm.apply(this, arguments);
}
function npmInstall(_) {
  return _npmInstall.apply(this, arguments);
}
function _npmInstall() {
  _npmInstall = _async_to_generator(function(param) {
    var cwd, registryUrl, ignoreScripts, useNvm, canUse, params;
    return _ts_generator(this, function(_state) {
      switch (_state.label) {
        case 0:
          cwd = param.cwd, registryUrl = param.registryUrl, ignoreScripts = param.ignoreScripts, useNvm = param.useNvm;
          return [
            4,
            canUseNpm()
          ];
        case 1:
          canUse = _state.sent();
          if (canUse) {
            params = [
              "install"
            ];
            if (registryUrl) {
              params.push("--registry=".concat(registryUrl));
            }
            if (ignoreScripts) {
              params.push("--ignore-scripts");
            }
            if (useNvm) {
              return [
                2,
                runInstallWithNvm("npm ".concat(params.join(" ")), {
                  cwd,
                  env: process.env
                })
              ];
            }
            return [
              2,
              execaWithStreamLog("npm", params, {
                cwd,
                env: process.env
              })
            ];
          }
          throw new Error("please install npm first");
      }
    });
  });
  return _npmInstall.apply(this, arguments);
}
function yarnInstall(_) {
  return _yarnInstall.apply(this, arguments);
}
function _yarnInstall() {
  _yarnInstall = _async_to_generator(function(param) {
    var cwd, registryUrl, ignoreScripts, useNvm, canUse, params;
    return _ts_generator(this, function(_state) {
      switch (_state.label) {
        case 0:
          cwd = param.cwd, registryUrl = param.registryUrl, ignoreScripts = param.ignoreScripts, useNvm = param.useNvm;
          return [
            4,
            canUseYarn()
          ];
        case 1:
          canUse = _state.sent();
          if (canUse) {
            params = [
              "install"
            ];
            if (registryUrl) {
              params.push("--registry=".concat(registryUrl));
            }
            if (ignoreScripts) {
              params.push("--ignore-scripts");
            }
            if (useNvm) {
              return [
                2,
                runInstallWithNvm("yarn ".concat(params.join(" ")), {
                  cwd,
                  env: process.env
                })
              ];
            }
            return [
              2,
              execaWithStreamLog("yarn", params, {
                cwd,
                env: process.env
              })
            ];
          }
          throw new Error("please install yarn first");
      }
    });
  });
  return _yarnInstall.apply(this, arguments);
}
function pnpmInstall(_) {
  return _pnpmInstall.apply(this, arguments);
}
function _pnpmInstall() {
  _pnpmInstall = _async_to_generator(function(param) {
    var cwd, registryUrl, ignoreScripts, useNvm, canUse, params;
    return _ts_generator(this, function(_state) {
      switch (_state.label) {
        case 0:
          cwd = param.cwd, registryUrl = param.registryUrl, ignoreScripts = param.ignoreScripts, useNvm = param.useNvm;
          return [
            4,
            canUsePnpm()
          ];
        case 1:
          canUse = _state.sent();
          if (canUse) {
            params = [
              "install"
            ];
            if (registryUrl) {
              params.push("--registry=".concat(registryUrl));
            }
            if (ignoreScripts) {
              params.push("--ignore-scripts");
            }
            if (useNvm) {
              return [
                2,
                runInstallWithNvm("yarn ".concat(params.join(" ")), {
                  cwd,
                  env: process.env
                })
              ];
            }
            return [
              2,
              execaWithStreamLog("pnpm", params, {
                cwd,
                env: process.env
              })
            ];
          }
          throw new Error("please install pnpm first");
      }
    });
  });
  return _pnpmInstall.apply(this, arguments);
}
export {
  execaWithStreamLog,
  npmInstall,
  pnpmInstall,
  runInstallWithNvm,
  yarnInstall
};
